@@ -16,6 +16,7 @@
 // along with this program. If not, see <http://www.gnu.org/licenses/>.
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 #include "application.h"
+#include "log.h"
 #include <mobius/database/connection_pool.h>
 #include <mobius/exception.inc>
 #include <mobius/exception_posix.inc>
@@ -83,10 +84,10 @@ static struct
   const std::string name = "Mobius Forensic Toolkit";
 
   //! \brief application version
-  const std::string version = "1.20";
+  const std::string version = "1.22";
 
   //! \brief application title
-  const std::string title = "Mobius v1.20";
+  const std::string title = "Mobius v1.22";
 
   //! \brief application copyright
   const std::string copyright = "Copyright (C) 2008,2009,2010,2011,2012,2013,2014,2015,2016,2017,2018,2019,2020 Eduardo Aguiar";
@@ -112,7 +113,7 @@ static struct
 } data_;
 
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-//! \brief initialize data structure
+//! \brief Initialize data structure
 //! \see https://specifications.freedesktop.org/basedir-spec/basedir-spec-latest.html
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 static void
@@ -130,7 +131,7 @@ load_data ()
   // config folder
   // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
   const char *xdg_config_home = getenv ("XDG_CONFIG_HOME");
-      
+
   if (xdg_config_home)
     data_.config_folder = xdg_config_home;
 
@@ -140,6 +141,7 @@ load_data ()
   data_.config_folder += std::string ("/") + data_.id;
 
   make_directory (data_.config_folder);
+  set_logfile_path (data_.config_folder + "/mobius.log");
       
   // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
   // cache folder
@@ -194,6 +196,14 @@ get_database ()
   return data_.pool.get_database ();
 }
 
+// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
+//! \brief Constructor
+// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
+application::application ()
+{
+  load_data ();
+}
+
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 //! \brief get application ID
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
