@@ -25,13 +25,19 @@
 #include "module.h"
 #include "ant.h"
 #include "application.h"
+#include "bookmarked_url.h"
+#include "call.h"
 #include "case.h"
+#include "chat_message.h"
 #include "cookie.h"
 #include "password.h"
 #include "password_hash.h"
 #include "profile.h"
+#include "text_autocomplete.h"
 #include "text_search.h"
+#include "visited_url.h"
 #include "pod/data.h"
+#include "pod/list.h"
 
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 //! \brief Create <i>item</i> Python object from C++ object
@@ -895,6 +901,28 @@ tp_f_remove_passwords (model_item_o *self, PyObject *)
   return mobius::py::pynone ();
 }
 
+// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
+//! \brief <i>count_passwords</i> method implementation
+//! \param self Object
+//! \param args Argument list
+// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
+static PyObject *
+tp_f_count_passwords (model_item_o *self, PyObject *)
+{
+  PyObject *ret = nullptr;
+
+  try
+    {
+      ret = mobius::py::pylong_from_std_int64_t (self->obj->count_passwords ());
+    }
+  catch (const std::exception& e)
+    {
+      PyErr_SetString (PyExc_Exception, e.what ());
+    }
+
+  return ret;
+}
+
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 //! \brief <i>new_password_hash</i> method implementation
 //! \param self Object
@@ -984,6 +1012,28 @@ tp_f_remove_password_hashes (model_item_o *self, PyObject *)
   return mobius::py::pynone ();
 }
 
+// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
+//! \brief <i>count_password_hashes</i> method implementation
+//! \param self Object
+//! \param args Argument list
+// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
+static PyObject *
+tp_f_count_password_hashes (model_item_o *self, PyObject *)
+{
+  PyObject *ret = nullptr;
+
+  try
+    {
+      ret = mobius::py::pylong_from_std_int64_t (self->obj->count_password_hashes ());
+    }
+  catch (const std::exception& e)
+    {
+      PyErr_SetString (PyExc_Exception, e.what ());
+    }
+
+  return ret;
+}
+
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 //! \brief <i>new_cookie</i> method implementation
 //! \param self Object
@@ -1073,6 +1123,28 @@ tp_f_remove_cookies (model_item_o *self, PyObject *)
   return mobius::py::pynone ();
 }
 
+// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
+//! \brief <i>count_cookies</i> method implementation
+//! \param self Object
+//! \param args Argument list
+// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
+static PyObject *
+tp_f_count_cookies (model_item_o *self, PyObject *)
+{
+  PyObject *ret = nullptr;
+
+  try
+    {
+      ret = mobius::py::pylong_from_std_int64_t (self->obj->count_cookies ());
+    }
+  catch (const std::exception& e)
+    {
+      PyErr_SetString (PyExc_Exception, e.what ());
+    }
+
+  return ret;
+}
+
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 //! \brief <i>new_profile</i> method implementation
 //! \param self Object
@@ -1263,6 +1335,587 @@ tp_f_remove_text_searches (model_item_o *self, PyObject *)
   return mobius::py::pynone ();
 }
 
+// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
+//! \brief <i>count_text_searches</i> method implementation
+//! \param self Object
+//! \param args Argument list
+// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
+static PyObject *
+tp_f_count_text_searches (model_item_o *self, PyObject *)
+{
+  PyObject *ret = nullptr;
+
+  try
+    {
+      ret = mobius::py::pylong_from_std_int64_t (self->obj->count_text_searches ());
+    }
+  catch (const std::exception& e)
+    {
+      PyErr_SetString (PyExc_Exception, e.what ());
+    }
+
+  return ret;
+}
+
+// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
+//! \brief <i>new_bookmarked_url</i> method implementation
+//! \param self Object
+//! \param args Argument list
+//! \return URL bookmark
+// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
+static PyObject *
+tp_f_new_bookmarked_url (model_item_o *self, PyObject *args)
+{
+  // parse input args
+  std::string arg_url;
+
+  try
+    {
+      arg_url = mobius::py::get_arg_as_std_string (args, 0);
+    }
+  catch (const std::exception& e)
+    {
+      PyErr_SetString (PyExc_TypeError, e.what ());
+      return nullptr;
+    }
+
+  // Execute C++ function
+  PyObject *ret = nullptr;
+
+  try
+    {
+      ret = PyMobius_Model_Bookmarked_Url_from_cpp (
+               self->obj->new_bookmarked_url (arg_url)
+            );
+    }
+  catch (const std::exception& e)
+    {
+      PyErr_SetString (PyExc_Exception, e.what ());
+    }
+
+  // Return value
+  return ret;
+}
+
+// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
+//! \brief <i>get_bookmarked_urls</i> method implementation
+//! \param self Object
+//! \param args Argument list
+//! \return URL bookmarks
+// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
+static PyObject *
+tp_f_get_bookmarked_urls (model_item_o *self, PyObject *)
+{
+  PyObject *ret = nullptr;
+
+  try
+    {
+      ret = mobius::py::pylist_from_cpp_container (
+              self->obj->get_bookmarked_urls (),
+              PyMobius_Model_Bookmarked_Url_from_cpp
+            );
+    }
+  catch (const std::exception& e)
+    {
+      PyErr_SetString (PyExc_Exception, e.what ());
+    }
+    
+  return ret;
+}
+
+// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
+//! \brief <i>remove_bookmarked_urls</i> method implementation
+//! \param self Object
+//! \param args Argument list
+// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
+static PyObject *
+tp_f_remove_bookmarked_urls (model_item_o *self, PyObject *)
+{
+  try
+    {
+      self->obj->remove_bookmarked_urls ();
+    }
+  catch (const std::exception& e)
+    {
+      PyErr_SetString (PyExc_Exception, e.what ());
+      return nullptr;
+    }
+
+  return mobius::py::pynone ();
+}
+
+// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
+//! \brief <i>count_bookmarked_urls</i> method implementation
+//! \param self Object
+//! \param args Argument list
+// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
+static PyObject *
+tp_f_count_bookmarked_urls (model_item_o *self, PyObject *)
+{
+  PyObject *ret = nullptr;
+
+  try
+    {
+      ret = mobius::py::pylong_from_std_int64_t (self->obj->count_bookmarked_urls ());
+    }
+  catch (const std::exception& e)
+    {
+      PyErr_SetString (PyExc_Exception, e.what ());
+    }
+
+  return ret;
+}
+
+// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
+//! \brief <i>new_visited_url</i> method implementation
+//! \param self Object
+//! \param args Argument list
+//! \return New visited URL
+// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
+static PyObject *
+tp_f_new_visited_url (model_item_o *self, PyObject *args)
+{
+  // parse input args
+  mobius::datetime::datetime arg_timestamp;
+  std::string arg_url;
+
+  try
+    {
+      arg_timestamp = mobius::py::get_arg_as_datetime (args, 0);
+      arg_url = mobius::py::get_arg_as_std_string (args, 1);
+    }
+  catch (const std::exception& e)
+    {
+      PyErr_SetString (PyExc_TypeError, e.what ());
+      return nullptr;
+    }
+
+  // Execute C++ function
+  PyObject *ret = nullptr;
+
+  try
+    {
+      ret = PyMobius_Model_Visited_Url_from_cpp (
+               self->obj->new_visited_url (arg_timestamp, arg_url)
+            );
+    }
+  catch (const std::exception& e)
+    {
+      PyErr_SetString (PyExc_Exception, e.what ());
+    }
+
+  // Return value
+  return ret;
+}
+
+// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
+//! \brief <i>get_visited_urls</i> method implementation
+//! \param self Object
+//! \param args Argument list
+//! \return Visited URLs
+// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
+static PyObject *
+tp_f_get_visited_urls (model_item_o *self, PyObject *)
+{
+  PyObject *ret = nullptr;
+
+  try
+    {
+      ret = mobius::py::pylist_from_cpp_container (
+              self->obj->get_visited_urls (),
+              PyMobius_Model_Visited_Url_from_cpp
+            );
+    }
+  catch (const std::exception& e)
+    {
+      PyErr_SetString (PyExc_Exception, e.what ());
+    }
+    
+  return ret;
+}
+
+// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
+//! \brief <i>remove_visited_urls</i> method implementation
+//! \param self Object
+//! \param args Argument list
+// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
+static PyObject *
+tp_f_remove_visited_urls (model_item_o *self, PyObject *)
+{
+  try
+    {
+      self->obj->remove_visited_urls ();
+    }
+  catch (const std::exception& e)
+    {
+      PyErr_SetString (PyExc_Exception, e.what ());
+      return nullptr;
+    }
+
+  return mobius::py::pynone ();
+}
+
+// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
+//! \brief <i>count_visited_urls</i> method implementation
+//! \param self Object
+//! \param args Argument list
+// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
+static PyObject *
+tp_f_count_visited_urls (model_item_o *self, PyObject *)
+{
+  PyObject *ret = nullptr;
+
+  try
+    {
+      ret = mobius::py::pylong_from_std_int64_t (self->obj->count_visited_urls ());
+    }
+  catch (const std::exception& e)
+    {
+      PyErr_SetString (PyExc_Exception, e.what ());
+    }
+
+  return ret;
+}
+
+// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
+//! \brief <i>new_chat_message</i> method implementation
+//! \param self Object
+//! \param args Argument list
+//! \return New Python object
+// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
+static PyObject *
+tp_f_new_chat_message (model_item_o *self, PyObject *args)
+{
+  // parse input args
+  mobius::datetime::datetime arg_timestamp;
+  std::string arg_sender;
+  mobius::pod::list arg_recipients;
+  mobius::pod::list arg_text;
+
+  try
+    {
+      arg_timestamp = mobius::py::get_arg_as_datetime (args, 0);
+      arg_sender = mobius::py::get_arg_as_std_string (args, 1);
+      arg_recipients = mobius::py::get_arg_as_cpp (args, 2, PyMobius_Pod_List_as_cpp);
+      arg_text = mobius::py::get_arg_as_cpp (args, 3, PyMobius_Pod_List_as_cpp);
+    }
+  catch (const std::exception& e)
+    {
+      PyErr_SetString (PyExc_TypeError, e.what ());
+      return nullptr;
+    }
+
+  // Execute C++ function
+  PyObject *ret = nullptr;
+
+  try
+    {
+      ret = PyMobius_Model_Chat_Message_from_cpp (
+               self->obj->new_chat_message (arg_timestamp, arg_sender, arg_recipients, arg_text)
+            );
+    }
+  catch (const std::exception& e)
+    {
+      PyErr_SetString (PyExc_Exception, e.what ());
+    }
+
+  // Return value
+  return ret;
+}
+
+// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
+//! \brief <i>get_chat_messages</i> method implementation
+//! \param self Object
+//! \param args Argument list
+//! \return List of objects
+// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
+static PyObject *
+tp_f_get_chat_messages (model_item_o *self, PyObject *)
+{
+  PyObject *ret = nullptr;
+
+  try
+    {
+      ret = mobius::py::pylist_from_cpp_container (
+              self->obj->get_chat_messages (),
+              PyMobius_Model_Chat_Message_from_cpp
+            );
+    }
+  catch (const std::exception& e)
+    {
+      PyErr_SetString (PyExc_Exception, e.what ());
+    }
+    
+  return ret;
+}
+
+// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
+//! \brief <i>remove_chat_messages</i> method implementation
+//! \param self Object
+//! \param args Argument list
+// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
+static PyObject *
+tp_f_remove_chat_messages (model_item_o *self, PyObject *)
+{
+  try
+    {
+      self->obj->remove_chat_messages ();
+    }
+  catch (const std::exception& e)
+    {
+      PyErr_SetString (PyExc_Exception, e.what ());
+      return nullptr;
+    }
+
+  return mobius::py::pynone ();
+}
+
+// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
+//! \brief <i>count_chat_messages</i> method implementation
+//! \param self Object
+//! \param args Argument list
+// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
+static PyObject *
+tp_f_count_chat_messages (model_item_o *self, PyObject *)
+{
+  PyObject *ret = nullptr;
+
+  try
+    {
+      ret = mobius::py::pylong_from_std_int64_t (self->obj->count_chat_messages ());
+    }
+  catch (const std::exception& e)
+    {
+      PyErr_SetString (PyExc_Exception, e.what ());
+    }
+
+  return ret;
+}
+
+// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
+//! \brief <i>new_call</i> method implementation
+//! \param self Object
+//! \param args Argument list
+//! \param New Python object
+// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
+static PyObject *
+tp_f_new_call (model_item_o *self, PyObject *args)
+{
+  // Parse input args
+  mobius::datetime::datetime arg_timestamp;
+  std::string arg_source;
+  mobius::pod::list arg_destination;
+  std::int64_t arg_duration;
+
+  try
+    {
+      arg_timestamp = mobius::py::get_arg_as_datetime (args, 0);
+      arg_source = mobius::py::get_arg_as_std_string (args, 1);
+      arg_destination = mobius::py::get_arg_as_cpp (args, 2, PyMobius_Pod_List_as_cpp);
+      arg_duration = mobius::py::get_arg_as_int64_t (args, 3);
+    }
+  catch (const std::exception& e)
+    {
+      PyErr_SetString (PyExc_TypeError, e.what ());
+      return nullptr;
+    }
+
+  // Execute C++ function
+  PyObject *ret = nullptr;
+
+  try
+    {
+      ret = PyMobius_Model_Call_from_cpp (
+              self->obj->new_call (arg_timestamp, arg_source, arg_destination, arg_duration)
+            );
+    }
+  catch (const std::exception& e)
+    {
+      PyErr_SetString (PyExc_Exception, e.what ());
+    }
+
+  return ret;
+}
+
+// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
+//! \brief <i>get_calls</i> method implementation
+//! \param self Object
+//! \return List of objects
+// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
+static PyObject *
+tp_f_get_calls (model_item_o *self, PyObject *)
+{
+  PyObject *ret = nullptr;
+
+  try
+    {
+      ret = mobius::py::pylist_from_cpp_container (
+              self->obj->get_calls (),
+              PyMobius_Model_Call_from_cpp
+            );
+    }
+  catch (const std::exception& e)
+    {
+      PyErr_SetString (PyExc_Exception, e.what ());
+    }
+
+  return ret;
+}
+
+// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
+//! \brief <i>remove_calls</i> method implementation
+//! \param self Object
+// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
+static PyObject *
+tp_f_remove_calls (model_item_o *self, PyObject *)
+{
+  try
+    {
+      self->obj->remove_calls ();
+    }
+  catch (const std::exception& e)
+    {
+      PyErr_SetString (PyExc_Exception, e.what ());
+      return nullptr;
+    }
+
+  return mobius::py::pynone ();
+}
+
+// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
+//! \brief <i>count_calls</i> method implementation
+//! \param self Object
+//! \return Number of items
+// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
+static PyObject *
+tp_f_count_calls (model_item_o *self, PyObject *)
+{
+  PyObject *ret = nullptr;
+
+  try
+    {
+      ret = mobius::py::pylong_from_std_int64_t (
+              self->obj->count_calls ()
+            );
+    }
+  catch (const std::exception& e)
+    {
+      PyErr_SetString (PyExc_Exception, e.what ());
+    }
+
+  return ret;
+}
+
+// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
+//! \brief <i>new_text_autocomplete</i> method implementation
+//! \param self Object
+//! \param args Argument list
+//! \param New Python object
+// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
+static PyObject *
+tp_f_new_text_autocomplete (model_item_o *self, PyObject *args)
+{
+  // Parse input args
+  std::string arg_field_name;
+  std::string arg_value;
+
+  try
+    {
+      arg_field_name = mobius::py::get_arg_as_std_string (args, 0);
+      arg_value = mobius::py::get_arg_as_std_string (args, 1);
+    }
+  catch (const std::exception& e)
+    {
+      PyErr_SetString (PyExc_TypeError, e.what ());
+      return nullptr;
+    }
+
+  // Execute C++ function
+  PyObject *ret = nullptr;
+
+  try
+    {
+      ret = PyMobius_Model_Text_Autocomplete_from_cpp (
+              self->obj->new_text_autocomplete (arg_field_name, arg_value)
+            );
+    }
+  catch (const std::exception& e)
+    {
+      PyErr_SetString (PyExc_Exception, e.what ());
+    }
+
+  return ret;
+}
+
+// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
+//! \brief <i>get_text_autocompletes</i> method implementation
+//! \param self Object
+//! \return List of objects
+// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
+static PyObject *
+tp_f_get_text_autocompletes (model_item_o *self, PyObject *)
+{
+  PyObject *ret = nullptr;
+
+  try
+    {
+      ret = mobius::py::pylist_from_cpp_container (
+              self->obj->get_text_autocompletes (),
+              PyMobius_Model_Text_Autocomplete_from_cpp
+            );
+    }
+  catch (const std::exception& e)
+    {
+      PyErr_SetString (PyExc_Exception, e.what ());
+    }
+
+  return ret;
+}
+
+// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
+//! \brief <i>remove_text_autocompletes</i> method implementation
+//! \param self Object
+// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
+static PyObject *
+tp_f_remove_text_autocompletes (model_item_o *self, PyObject *)
+{
+  try
+    {
+      self->obj->remove_text_autocompletes ();
+    }
+  catch (const std::exception& e)
+    {
+      PyErr_SetString (PyExc_Exception, e.what ());
+      return nullptr;
+    }
+
+  return mobius::py::pynone ();
+}
+
+// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
+//! \brief <i>count_text_autocompletes</i> method implementation
+//! \param self Object
+//! \return Number of items
+// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
+static PyObject *
+tp_f_count_text_autocompletes (model_item_o *self, PyObject *)
+{
+  PyObject *ret = nullptr;
+
+  try
+    {
+      ret = mobius::py::pylong_from_std_int64_t (
+              self->obj->count_text_autocompletes ()
+            );
+    }
+  catch (const std::exception& e)
+    {
+      PyErr_SetString (PyExc_Exception, e.what ());
+    }
+
+  return ret;
+}
+
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 //! \brief Methods structure
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
@@ -1400,6 +2053,12 @@ static PyMethodDef tp_methods[] =
     METH_VARARGS,
     "Remove passwords"
   },
+  {
+    (char *) "count_passwords",
+    (PyCFunction) tp_f_count_passwords,
+    METH_VARARGS,
+    "Count passwords"
+  },
   {
     (char *) "new_password_hash",
     (PyCFunction) tp_f_new_password_hash,
@@ -1418,6 +2077,12 @@ static PyMethodDef tp_methods[] =
     METH_VARARGS,
     "Remove password hashes"
   },
+  {
+    (char *) "count_password_hashes",
+    (PyCFunction) tp_f_count_password_hashes,
+    METH_VARARGS,
+    "Count password hashes"
+  },
   {
     (char *) "new_cookie",
     (PyCFunction) tp_f_new_cookie,
@@ -1436,6 +2101,12 @@ static PyMethodDef tp_methods[] =
     METH_VARARGS,
     "Remove cookies"
   },
+  {
+    (char *) "count_cookies",
+    (PyCFunction) tp_f_count_cookies,
+    METH_VARARGS,
+    "Count cookies"
+  },
   {
     (char *) "new_profile",
     (PyCFunction) tp_f_new_profile,
@@ -1472,6 +2143,132 @@ static PyMethodDef tp_methods[] =
     METH_VARARGS,
     "Remove text searches"
   },
+  {
+    (char *) "count_text_searches",
+    (PyCFunction) tp_f_count_text_searches,
+    METH_VARARGS,
+    "Count text searches"
+  },
+  {
+    (char *) "new_bookmarked_url",
+    (PyCFunction) tp_f_new_bookmarked_url,
+    METH_VARARGS,
+    "Create new bookmarked URL object"
+  },
+  {
+    (char *) "get_bookmarked_urls",
+    (PyCFunction) tp_f_get_bookmarked_urls,
+    METH_VARARGS,
+    "Get bookmarked URLs"
+  },
+  {
+    (char *) "remove_bookmarked_urls",
+    (PyCFunction) tp_f_remove_bookmarked_urls,
+    METH_VARARGS,
+    "Remove bookmarked URLs"
+  },
+  {
+    (char *) "count_bookmarked_urls",
+    (PyCFunction) tp_f_count_bookmarked_urls,
+    METH_VARARGS,
+    "Count bookmarked URLs"
+  },
+  {
+    (char *) "new_visited_url",
+    (PyCFunction) tp_f_new_visited_url,
+    METH_VARARGS,
+    "Create new visited URL object"
+  },
+  {
+    (char *) "get_visited_urls",
+    (PyCFunction) tp_f_get_visited_urls,
+    METH_VARARGS,
+    "Get visited URLs"
+  },
+  {
+    (char *) "remove_visited_urls",
+    (PyCFunction) tp_f_remove_visited_urls,
+    METH_VARARGS,
+    "Remove visited URLs"
+  },
+  {
+    (char *) "count_visited_urls",
+    (PyCFunction) tp_f_count_visited_urls,
+    METH_VARARGS,
+    "Count visited URLs"
+  },
+  {
+    (char *) "new_chat_message",
+    (PyCFunction) tp_f_new_chat_message,
+    METH_VARARGS,
+    "Create new chat message object"
+  },
+  {
+    (char *) "get_chat_messages",
+    (PyCFunction) tp_f_get_chat_messages,
+    METH_VARARGS,
+    "Get chat messages"
+  },
+  {
+    (char *) "remove_chat_messages",
+    (PyCFunction) tp_f_remove_chat_messages,
+    METH_VARARGS,
+    "Remove chat messages"
+  },
+  {
+    (char *) "count_chat_messages",
+    (PyCFunction) tp_f_count_chat_messages,
+    METH_VARARGS,
+    "Count chat messages"
+  },
+  {
+    (char *) "new_call",
+    (PyCFunction) tp_f_new_call,
+    METH_VARARGS,
+    "Create new call object"
+  },
+  {
+    (char *) "get_calls",
+    (PyCFunction) tp_f_get_calls,
+    METH_VARARGS,
+    "Get call objects"
+  },
+  {
+    (char *) "remove_calls",
+    (PyCFunction) tp_f_remove_calls,
+    METH_VARARGS,
+    "Remove call objects"
+  },
+  {
+    (char *) "count_calls",
+    (PyCFunction) tp_f_count_calls,
+    METH_VARARGS,
+    "Count call objects"
+  },
+  {
+    (char *) "new_text_autocomplete",
+    (PyCFunction) tp_f_new_text_autocomplete,
+    METH_VARARGS,
+    "Create new text_autocomplete object"
+  },
+  {
+    (char *) "get_text_autocompletes",
+    (PyCFunction) tp_f_get_text_autocompletes,
+    METH_VARARGS,
+    "Get text_autocomplete objects"
+  },
+  {
+    (char *) "remove_text_autocompletes",
+    (PyCFunction) tp_f_remove_text_autocompletes,
+    METH_VARARGS,
+    "Remove text_autocomplete objects"
+  },
+  {
+    (char *) "count_text_autocompletes",
+    (PyCFunction) tp_f_count_text_autocompletes,
+    METH_VARARGS,
+    "Count text_autocomplete objects"
+  },
   {NULL, NULL, 0, NULL} // sentinel
 };
 
