@@ -1,6 +1,6 @@
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 // Mobius Forensic Toolkit
-// Copyright (C) 2008,2009,2010,2011,2012,2013,2014,2015,2016,2017,2018,2019 Eduardo Aguiar
+// Copyright (C) 2008,2009,2010,2011,2012,2013,2014,2015,2016,2017,2018,2019,2020 Eduardo Aguiar
 //
 // This program is free software; you can redistribute it and/or modify it
 // under the terms of the GNU General Public License as published by the
@@ -31,20 +31,25 @@
 #include "datetime/module.h"
 #include "decoder/module.h"
 #include "disk/module.h"
-#include "filesystem/module.h"
+#include "encoder/module.h"
 #include "imagefile/module.h"
 #include "io/module.h"
 #include "model/module.h"
 #include "os/module.h"
 #include "partition/module.h"
-#include "registry/module.h"
+#include "pod/module.h"
 #include "system/module.h"
 #include "turing/module.h"
-#include <mobius/exception.inc>
-#include <stdexcept>
+#include "vfs/module.h"
 
+#include <functional>
+#include <stdexcept>
+#include <utility>
+
+namespace
+{
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-//! \brief module methods
+//! \brief Module methods
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 static PyMethodDef module_methods[] =
 {
@@ -57,7 +62,32 @@ static PyMethodDef module_methods[] =
 };
 
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-//! \brief module initialisation function
+//! \brief Sub-modules
+// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
+static std::pair <std::string, std::function<PyObject *()>> sub_modules[] =
+{
+  {"core", new_core_module },
+  {"crypt", new_crypt_module },
+  {"database", new_database_module },
+  {"datetime", new_datetime_module },
+  {"decoder", new_decoder_module },
+  {"disk", new_disk_module },
+  {"encoder", new_encoder_module },
+  {"imagefile", new_imagefile_module },
+  {"io", new_io_module },
+  {"model", new_model_module },
+  {"os", new_os_module },
+  {"partition", new_partition_module },
+  {"pod", new_pod_module },
+  {"system", new_system_module },
+  {"turing", new_turing_module },
+  {"vfs", new_vfs_module },
+};
+
+} // namespace
+
+// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
+//! \brief Module initialisation function
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 PyMODINIT_FUNC
 initmobius ()
@@ -80,50 +110,11 @@ initmobius ()
   PyDateTime_IMPORT;
 
   // Build submodules
-  PyObject *core_module = new_core_module ();
-  PyModule_AddObject (mobius_module, "core", core_module);
-
-  PyObject *crypt_module = new_crypt_module ();
-  PyModule_AddObject (mobius_module, "crypt", crypt_module);
-
-  PyObject *database_module = new_database_module ();
-  PyModule_AddObject (mobius_module, "database", database_module);
-
-  PyObject *datetime_module = new_datetime_module ();
-  PyModule_AddObject (mobius_module, "datetime", datetime_module);
-
-  PyObject *decoder_module = new_decoder_module ();
-  PyModule_AddObject (mobius_module, "decoder", decoder_module);
-
-  PyObject *disk_module = new_disk_module ();
-  PyModule_AddObject (mobius_module, "disk", disk_module);
-
-  PyObject *filesystem_module = new_filesystem_module ();
-  PyModule_AddObject (mobius_module, "filesystem", filesystem_module);
-
-  PyObject *imagefile_module = new_imagefile_module ();
-  PyModule_AddObject (mobius_module, "imagefile", imagefile_module);
-
-  PyObject *io_module = new_io_module ();
-  PyModule_AddObject (mobius_module, "io", io_module);
-
-  PyObject *model_module = new_model_module ();
-  PyModule_AddObject (mobius_module, "model", model_module);
-
-  PyObject *os_module = new_os_module ();
-  PyModule_AddObject (mobius_module, "os", os_module);
-
-  PyObject *partition_module = new_partition_module ();
-  PyModule_AddObject (mobius_module, "partition", partition_module);
-
-  PyObject *registry_module = new_registry_module ();
-  PyModule_AddObject (mobius_module, "registry", registry_module);
-
-  PyObject *system_module = new_system_module ();
-  PyModule_AddObject (mobius_module, "system", system_module);
-
-  PyObject *turing_module = new_turing_module ();
-  PyModule_AddObject (mobius_module, "turing", turing_module);
+  for (const auto& p : sub_modules)
+    {
+      PyObject *s_module = p.second ();
+      PyModule_AddObject (mobius_module, p.first.c_str (), s_module);
+    }
 
   // deprecated: this types must be enclosed in submodules
   Py_INCREF (&api_dataholder_t);
